@@ -3,7 +3,7 @@
 
 #include <RcppArmadillo.h>
 
-arma::mat clr_coordinates(arma::mat X);
+arma::mat clr_coordinates(arma::mat &X);
 
 arma::mat inv_clr_coordinates(arma::mat clrX);
 
@@ -11,7 +11,7 @@ arma::mat ilr_basis_default(unsigned int dim);
 
 arma::mat ilr_basis_simplex(unsigned int dim);
 
-arma::mat ilr_coordinates(arma::mat X);
+arma::mat ilr_coordinates(arma::mat &X);
 
 arma::mat ilr_coordinates_with_basis(arma::mat X, arma::mat B);
 
